@@ -1,16 +1,8 @@
 normalize1 <- function(rwl,n,prewhiten){
-  ar.func=function(y){
-    idx.goody <- !is.na(y)
-    ar1 <- ar(y[idx.goody])
-    y2 <- ar1$resid+ar1$x.mean
-    y[idx.goody] <- y2
-    y
-  }
-
   # Run hanning filter over the data if n isn't NULL
   # divide by mean if n is null
   if(is.null(n)){
-    master.stats <- apply(rwl,2,mean,na.rm=T)
+    master.stats <- colMeans(rwl, na.rm=TRUE)
     master.df <- sweep(rwl,2,master.stats,"/")
   } else {
     master.stats <- apply(rwl,2,hanning,n)
@@ -19,7 +11,7 @@ normalize1 <- function(rwl,n,prewhiten){
   # Apply ar if prewhiten
   if(prewhiten){
     # take note of, ignore later, any columns without at least four observations
-    idx.good <- apply(master.df,2, function(x) {sum(!is.na(x)) > 3})
+    idx.good <- colSums(!is.na(master.df)) > 3
     master.df <- apply(master.df,2,ar.func)
   } else {
     idx.good <- rep(TRUE, ncol(master.df))
